============================================
Launch and manage stacks using the Dashboard
============================================

The Orchestration service provides a template-based
orchestration engine for the OpenStack cloud. Orchestration
services create and manage cloud infrastructure
resources such as storage, networking, instances, and
applications as a repeatable running environment.

Administrators use templates to create stacks, which are
collections of resources. For example, a stack might
include instances, floating IPs, volumes,
security groups, or users. The Orchestration service
offers access to all OpenStack
core services via a single modular template, with additional
orchestration capabilities such as auto-scaling and basic
high availability.

For information about:

* administrative tasks on the command-line, see
  the `OpenStack Administrator Guide
  <https://docs.openstack.org/admin-guide/cli-admin-manage-stacks.html>`__.

  .. note::

     There are no administration-specific tasks that can be done through
     the Dashboard.

* the basic creation and deletion of Orchestration stacks, refer to
  the `OpenStack End User Guide
  <https://docs.openstack.org/user-guide/dashboard-stacks.html>`__.

